@@ -317,9 +317,7 @@ parse_richtext <- function(
   old_gp <- gp
 
   if (md) {
-    text <- markdown::markdownToHTML(text = text,
-              options = c("use_xhtml", "fragment_only"))
-
+    text <- markdown::mark(text = text)
   }
   # Deal with <br> now, they are a pain to handle after parsing
   text <- gsub("<br>", "\n", text, fixed = TRUE)
